# skilleter-modules

A collection of Python modules used in my various other Python projects (readable, skilleter-thingy, skilleter-extras)

## colour.py

Functions for writing coloured text using ANSI control code sequences

## dc_curses.py, dc_defaults.py, dc_util.py, dircolors.py

Colour filesystem objects similar to ls.

Large parts of this code are Copyright 2019 Allen Wild <allenwild93@gmail.com> released under the Apache-2.0 licence.

## files.py

Miscellaneous file-related functions - backup creation, file-type detection, etc.

## git.py

A git library

## gitlab.py

GitLab access module - due to be deprecated as I no longer support GitLab

## path.py

Filesystem path-related functions

## popup.py

Popup window class for curses

## run.py

Wrapper around the subprocess module, providing additional functionality

## tfm_pane.py

Console-pane-handling code for TFM - will probably be moved into the TFM project when that is split out from skilleter-thingy

## tidy.py

Functions for tidying log files - this may be moved into the skilleter-readable project at some point
